==> zio-aws-iotsecuretunneling_2.13-5.17.234.1-sources.jar: zio/aws/iotsecuretunneling/model/package.scala <==
package zio.aws.iotsecuretunneling
import zio.aws.iotsecuretunneling.model.primitives.{TagKey, Service}
import zio.prelude.Subtype
import java.time.Instant
import zio.aws.iotsecuretunneling.model.primitives.DeleteFlag.Type
package object model {
  import scala.jdk.CollectionConverters._
  object primitives {
    object AmazonResourceName extends Subtype[String]
    type AmazonResourceName =
      zio.aws.iotsecuretunneling.model.primitives.AmazonResourceName.Type
    object ClientAccessToken extends Subtype[String]
    type ClientAccessToken =
      zio.aws.iotsecuretunneling.model.primitives.ClientAccessToken.Type
    object DateType extends Subtype[Instant]
    type DateType = zio.aws.iotsecuretunneling.model.primitives.DateType.Type
    object DeleteFlag extends Subtype[Boolean]
    type DeleteFlag =
      zio.aws.iotsecuretunneling.model.primitives.DeleteFlag.Type
    object Description extends Subtype[String]
    type Description =
      zio.aws.iotsecuretunneling.model.primitives.Description.Type
    object MaxResults extends Subtype[Int]
    type MaxResults =
      zio.aws.iotsecuretunneling.model.primitives.MaxResults.Type
    object NextToken extends Subtype[String]
    type NextToken = zio.aws.iotsecuretunneling.model.primitives.NextToken.Type
    object Service extends Subtype[String]
    type Service = zio.aws.iotsecuretunneling.model.primitives.Service.Type
    object TagKey extends Subtype[String]
    type TagKey = zio.aws.iotsecuretunneling.model.primitives.TagKey.Type
    object TagValue extends Subtype[String]
    type TagValue = zio.aws.iotsecuretunneling.model.primitives.TagValue.Type
    object ThingName extends Subtype[String]
    type ThingName = zio.aws.iotsecuretunneling.model.primitives.ThingName.Type
    object TimeoutInMin extends Subtype[Int]
    type TimeoutInMin =
      zio.aws.iotsecuretunneling.model.primitives.TimeoutInMin.Type
    object TunnelArn extends Subtype[String]
    type TunnelArn = zio.aws.iotsecuretunneling.model.primitives.TunnelArn.Type
    object TunnelId extends Subtype[String]
    type TunnelId = zio.aws.iotsecuretunneling.model.primitives.TunnelId.Type
  }
  type ServiceList = List[Service]
  type TagKeyList = List[TagKey]
  type TagList = List[zio.aws.iotsecuretunneling.model.Tag]
  type TunnelSummaryList = List[zio.aws.iotsecuretunneling.model.TunnelSummary]
}

==> zio-aws-iotsecuretunneling_3-5.17.196.1-sources.jar: zio/aws/iotsecuretunneling/model/package.scala <==
package zio.aws.iotsecuretunneling
import zio.aws.iotsecuretunneling.model.primitives.{TagKey, Service}
import zio.prelude.Subtype
import java.time.Instant
import zio.aws.iotsecuretunneling.model.primitives.DeleteFlag.Type
package object model {
  import scala.jdk.CollectionConverters.*
  object primitives {
    object AmazonResourceName extends Subtype[String]
    type AmazonResourceName =
      zio.aws.iotsecuretunneling.model.primitives.AmazonResourceName.Type
    object ClientAccessToken extends Subtype[String]
    type ClientAccessToken =
      zio.aws.iotsecuretunneling.model.primitives.ClientAccessToken.Type
    object DateType extends Subtype[Instant]
    type DateType = zio.aws.iotsecuretunneling.model.primitives.DateType.Type
    object DeleteFlag extends Subtype[Boolean]
    type DeleteFlag =
      zio.aws.iotsecuretunneling.model.primitives.DeleteFlag.Type
    object Description extends Subtype[String]
    type Description =
      zio.aws.iotsecuretunneling.model.primitives.Description.Type
    object MaxResults extends Subtype[Int]
    type MaxResults =
      zio.aws.iotsecuretunneling.model.primitives.MaxResults.Type
    object NextToken extends Subtype[String]
    type NextToken = zio.aws.iotsecuretunneling.model.primitives.NextToken.Type
    object Service extends Subtype[String]
    type Service = zio.aws.iotsecuretunneling.model.primitives.Service.Type
    object TagKey extends Subtype[String]
    type TagKey = zio.aws.iotsecuretunneling.model.primitives.TagKey.Type
    object TagValue extends Subtype[String]
    type TagValue = zio.aws.iotsecuretunneling.model.primitives.TagValue.Type
    object ThingName extends Subtype[String]
    type ThingName = zio.aws.iotsecuretunneling.model.primitives.ThingName.Type
    object TimeoutInMin extends Subtype[Int]
    type TimeoutInMin =
      zio.aws.iotsecuretunneling.model.primitives.TimeoutInMin.Type
    object TunnelArn extends Subtype[String]
    type TunnelArn = zio.aws.iotsecuretunneling.model.primitives.TunnelArn.Type
    object TunnelId extends Subtype[String]
    type TunnelId = zio.aws.iotsecuretunneling.model.primitives.TunnelId.Type
  }
  type ServiceList = List[Service]
  type TagKeyList = List[TagKey]
  type TagList = List[zio.aws.iotsecuretunneling.model.Tag]
  type TunnelSummaryList = List[zio.aws.iotsecuretunneling.model.TunnelSummary]
}
